<?php

namespace FiloBlu\Popup\Block;

use FiloBlu\Popup\Model\PopupFactory;
use Magento\Cms\Model\Template\FilterProvider;
use Magento\Framework\UrlInterface;
use Magento\Framework\View\Element\Template;
use Magento\Framework\View\Element\Template\Context;

/**
 *
 */
class Popup extends Template
{
    const CUSTOM_MEDIA_PATH = 'filoblu/popup';

    protected $_popupFactory;
    protected $_filterProvider;
    protected $_popupData;
    protected $_template = 'popup.phtml';

    /**
     * @param \Magento\Framework\View\Element\Template\Context $context
     * @param \FiloBlu\Popup\Model\PopupFactory $popupFactory
     * @param \Magento\Cms\Model\Template\FilterProvider $filterProvider
     * @param array $data
     */
    public function __construct(
        Context $context,
        PopupFactory $popupFactory,
        FilterProvider $filterProvider,
        array $data = []
    ) {
        parent::__construct($context, $data);
        $this->_popupFactory = $popupFactory;
        $this->_filterProvider = $filterProvider;
    }

    /**
     * @return mixed
     */
    public function getCookieDuration()
    {
        return $this->getPopupData()['cookie_duration'];
    }

    /**
     * @return mixed
     */
    public function getPopupData()
    {
        if (!$this->_popupData && $this->getPopupId()) {
            $model = $this->_popupFactory->create();
            $model->load($this->getPopupId());
            $this->_popupData = $model->getData();
        }

        return $this->_popupData;
    }

    /**
     * @return mixed
     */
    public function getTitle()
    {
        return $this->getPopupData()['title'];
    }

    /**
     * @return mixed
     */
    public function getDescription()
    {
        return $this->getPopupData()['description'];
    }

    /**
     * @return mixed
     */
    public function getImage()
    {
        return $this->getPopupData()['image'];
    }

    /**
     * @return mixed
     */
    public function isImageLinkEnabled()
    {
        return $this->getPopupData()['link_image'];
    }

    /**
     * @return mixed
     */
    public function getLink()
    {
        return $this->getPopupData()['link'];
    }

    /**
     * @return mixed
     */
    public function getPopupDeplay()
    {
        return $this->getPopupData()['delay'];
    }

    /**
     * @return mixed
     */
    public function getCtaText()
    {
        return $this->getPopupData()['link_text'];
    }

    /**
     * @return mixed
     */
    public function getCssStyle()
    {
        return $this->getPopupData()['css_style'];
    }

    /**
     * @param $imageName
     * @return string
     * @throws \Magento\Framework\Exception\NoSuchEntityException
     */
    public function getImageUrl($imageName)
    {
        return $this->_storeManager->getStore()->getBaseUrl(
                UrlInterface::URL_TYPE_MEDIA
            ) . self::CUSTOM_MEDIA_PATH . '/' . $imageName;
    }

    /**
     * @param $string
     * @return mixed
     * @throws \Magento\Framework\Exception\NoSuchEntityException
     */
    public function getFilteredContent($string)
    {
        return $this->_filterProvider->getBlockFilter()->setStoreId($this->_storeManager->getStore()->getId())->filter(
            $string
        );
    }

    /**
     * Render block HTML
     *
     * @return string
     * @throws \Magento\Framework\Exception\NoSuchEntityException
     */
    public function _toHtml()
    {
        if ((in_array($this->currentStoreId(), $this->getStoreIds()) || in_array(
                    0,
                    $this->getStoreIds()
                )) && $this->isEnabled()) {
            return parent::_toHtml();
        }

        return '';
    }

    /**
     * @return int
     * @throws \Magento\Framework\Exception\NoSuchEntityException
     */
    public function currentStoreId()
    {
        return $this->_storeManager->getStore()->getId();
    }

    /**
     * @return false|string[]
     */
    public function getStoreIds()
    {
        return explode(',', $this->getPopupData()['store_ids']);
    }

    /**
     * @return mixed
     */
    public function isEnabled()
    {
        return $this->getPopupData()['enabled'];
    }

}
