<?php

namespace FiloBlu\Popup\Controller\Adminhtml\Popup;

use Exception;
use FiloBlu\Popup\Helper\Data;
use FiloBlu\Popup\Model\PopupFactory;
use Magento\Backend\App\Action;
use Magento\Framework\App\Filesystem\DirectoryList;
use Magento\Framework\App\Request\DataPersistorInterface;
use Magento\Framework\Exception\LocalizedException;
use Magento\Framework\Filesystem;
use RuntimeException;

/**
 *
 */
class Save extends Action
{
    protected $dataPersistor;
    protected $_popupFactory;
    protected $_mediaDirectory;
    protected $_helper;

    /**
     * @param \Magento\Backend\App\Action\Context $context
     * @param \Magento\Framework\App\Request\DataPersistorInterface $dataPersistor
     * @param \FiloBlu\Popup\Model\PopupFactory $popupFactory
     * @param \Magento\Framework\Filesystem $filesystem
     * @param \FiloBlu\Popup\Helper\Data $helper
     * @throws \Magento\Framework\Exception\FileSystemException
     */
    public function __construct(
        Action\Context $context,
        DataPersistorInterface $dataPersistor,
        PopupFactory $popupFactory,
        Filesystem $filesystem,
        Data $helper
    ) {
        parent::__construct($context);
        $this->dataPersistor = $dataPersistor;
        $this->_popupFactory = $popupFactory;
        $this->_mediaDirectory = $filesystem->getDirectoryWrite(DirectoryList::MEDIA);
        $this->_helper = $helper;
    }

    public function execute()
    {
        $data = $this->getRequest()->getPostValue();
        $resultRedirect = $this->resultRedirectFactory->create();
        if ($data) {
            $model = $this->_popupFactory->create();

            if ($this->getRequest()->getParam('id')) {
                $model->load($this->getRequest()->getParam('id'));
            }


            if (isset($data['image'][0]['name'])) {
                $fileName = $data['image'][0]['name'];
            } else {
                $fileName = '';
            }

            $model->setTitle($data['title']);
            $model->setDescription($data['description']);
            $model->setImage($fileName);
            $model->setLinkImage($data['link_image']);
            $model->setEnabled($data['enabled']);
            $model->setLink($data['link']);
            $model->setLinkText($data['link_text']);

            $storeIds = implode(',', $data['store_ids']);
            $model->setStoreIds($storeIds);

            $model->setCookieDuration($data['cookie_duration']);
            $model->setDelay($data['delay']);
            $model->setCssStyle($data['css_style']);


            try {
                if ($fileName != '') {
                    $this->moveImageFromTmp($fileName);
                }
                $model->save();
                $this->messageManager->addSuccessMessage(__('Data Saved Successfully'));
                $this->dataPersistor->clear('filoblu_popup');

                if ($this->getRequest()->getParam('back')) {
                    return $resultRedirect->setPath('*/*/edit', ['id' => $model->getId(), '_current' => true]);
                }

                return $resultRedirect->setPath('*/*/');
            } catch (LocalizedException $e) {
                $this->messageManager->addError($e->getMessage());
            } catch (RuntimeException $e) {
                $this->messageManager->addError($e->getMessage());
            } catch (Exception $e) {
                $this->messageManager->addException($e, $e->getMessage());
            }

            $this->dataPersistor->set('filoblu_popup', $data);
            return $resultRedirect->setPath('*/*/edit', ['id' => $this->getRequest()->getParam('id')]);
        }
        return $resultRedirect->setPath('*/*/edit');
    }

    protected function moveImageFromTmp($fileName)
    {
        $_directory = $this->_helper->getMediaDirectory();

        if (!file_exists($_directory)) {
            mkdir($_directory, 0777, true);
        }

        $currentFilePath = $this->_helper->getMediaTmpDirectory() . $fileName;
        $newFilePath = $_directory . $fileName;

        if (file_exists($currentFilePath)) {
            rename($currentFilePath, $newFilePath);
        }
    }

    /**
     * Determines whether current user is allowed to access Action
     *
     * @return bool
     */
    protected function _isAllowed()
    {
        return $this->_authorization->isAllowed('Magento_Backend::content');
    }

}
